from .GeneralGuess import GeneralGuess
from random import randint


class GuessNumber(GeneralGuess):
    def __init__(self):
        GeneralGuess.__init__(self)

    def guess(self, n):
        if n == self.number:
            print("You have the right number")
        elif n < self.number:
            print("Your number is below")
        elif n > self.number:
            print("Your number is high")

    def change_guess(self):
        self.number = randint(1, 1000)

    def get_answer(self):
        return self.number


from random import randint


class GeneralGuess:
    def __init__(self):
            self.number = randint(1, 1000)

    def guess(self, n):
        pass

    def change_guess(self):
        pass

    def get_answer(self):
        if not self.is_letter:
            return self.number
        else:
            return self.is_letter



from .GeneralGuess import GeneralGuess
from random import randint
letters = ['a', 'b', 'c', 'd', 'e', 'f', 'g', 'h', 'i', 'j', 'k', 'l', 'm', 'n', 'o', 'p', 'q', 'r', 's', 't',
           'u', 'v', 'w', 'x', 'y', 'z']


class GuessLetter(GeneralGuess):
    def __init__(self):
        self.number = randint(1, 25)
        self.letter = letters[self.number]

    def guess(self, n):
        position = letters.index(n)
        if position == self.number:
            print("You have the right letter")
        elif position < self.number:
            print("Your letter is below")
        elif position > self.number:
            print("Your letter is high")

    def change_guess(self):
        self.number = randint(1, 25)

    def get_answer(self):
        return letters[self.number]
